const assert = require('assert'),
      suite = require('testingey').createSuite('fakedb'),
      db = require('../lib/fakedb').init('test.fdb');

db.on('load', function () {

  suite.setUp(function () {
    for (var i = 0; i < 10; ++i) {
      db.add({ index: i, value: i*i });
    }
    db.key('index', numeric = true);
  });

  suite.tearDown(function () {
    db.purge();
  });

  suite.spec('Testing db.add()', function () {
    var current = db.count();
    db.add({ index: 100, value: 100*100 });
    assert.equal(db.count(), current + 1);
  });

  suite.spec('Testing db.get()', function () {
    var key = db.add({ index: 101, value: 101*101 });
    var obj = db.get(key);
    assert.deepEqual(obj.doc, { index: 101, value: 101*101 });
  });

  suite.spec('Testing db.all() with no argument', function () {
    var current = db.count();
    var records = db.all();
    assert.equal(records.length, current);
  });

  suite.spec('Testing db.all() with query params', function () {
    var records = db.all({ where: { index: 101 } });
    assert.ok(records);
    assert.equal(records.length, 1);
    assert.deepEqual(records[0].doc, { index: 101, value: 101*101 });
  });

  suite.spec('Testing db.all() with callback filter', function () {
    var records = db.all(function (obj) {
      return (obj.doc.index && obj.doc.index < 5);
    });
    assert.ok(records);
    assert.equal(records.length, 4);
  });

  suite.spec('Testing db.purge()', function () {
    db.purge();
    assert.equal(db.count(), 0);
  });

  suite.run();

});
